@@ -1,7 +1,7 @@
 // synthv1widget_controls.cpp
 //
 /****************************************************************************
-   Copyright (C) 2012-2015, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2019, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -24,13 +24,41 @@
 #include "synthv1_controls.h"
 #include "synthv1_config.h"
 
+#include <QItemDelegate>
 #include <QHeaderView>
-
 #include <QSpinBox>
 #include <QLineEdit>
 #include <QComboBox>
 
 
+//----------------------------------------------------------------------------
+// synthv1widget_controls::ItemDelegate -- Custom (tree) list item delegate.
+
+class synthv1widget_controls::ItemDelegate : public QItemDelegate
+{
+public:
+
+	// ctor.
+	ItemDelegate(QObject *pParent = 0);
+
+	// QItemDelegate interface...
+	QSize sizeHint(
+		const QStyleOptionViewItem& option,
+		const QModelIndex& index) const;
+
+	QWidget *createEditor(QWidget *pParent,
+		const QStyleOptionViewItem& option,
+		const QModelIndex& index) const;
+
+	void setEditorData(QWidget *pEditor,
+		const QModelIndex& index) const;
+
+	void setModelData(QWidget *pEditor,
+		QAbstractItemModel *pModel,
+		const QModelIndex& index) const;
+};
+
+
 //----------------------------------------------------------------------------
 // MIDI Controller Names - Default controller names hash map.
 
@@ -111,7 +139,7 @@ const synthv1widget_controls::Names& synthv1widget_controls::controllerNames (vo
 		{126, QT_TR_NOOP("Mono Operation") },
 		{127, QT_TR_NOOP("Poly Operation") },
 
-		{  0, NULL }
+		{  0, nullptr }
 	};
 
 	static Names s_controllerNames;
@@ -146,7 +174,7 @@ const synthv1widget_controls::Names& synthv1widget_controls::rpnNames (void)
 		{  3, QT_TR_NOOP("Tuning Program") },
 		{  4, QT_TR_NOOP("Tuning Bank") },
 
-		{  0, NULL }
+		{  0, nullptr }
 	};
 
 	static Names s_rpnNames;
@@ -197,7 +225,7 @@ const synthv1widget_controls::Names& synthv1widget_controls::nrpnNames (void)
 		{ 3840, QT_TR_NOOP("Drum Chorus Send") },
 		{ 3968, QT_TR_NOOP("Drum Variation Send") },
 
-		{    0, NULL }
+		{    0, nullptr }
 	};
 
 	static struct
@@ -256,7 +284,7 @@ const synthv1widget_controls::Names& synthv1widget_controls::nrpnNames (void)
 		{ 80, QT_TR_NOOP("Mute Triangle") },
 		{ 81, QT_TR_NOOP("Open Triangle") },
 
-		{  0, NULL }
+		{  0, nullptr }
 	};
 
 	static Names s_nrpnNames;
@@ -310,7 +338,7 @@ const synthv1widget_controls::Names& synthv1widget_controls::control14Names (voi
 		{ 18, QT_TR_NOOP("General Purpose Slider 3 (14bit)") },
 		{ 19, QT_TR_NOOP("General Purpose Slider 4 (14bit)") },
 
-		{  0, NULL }
+		{  0, nullptr }
 	};
 
 	static Names s_control14Names;
@@ -420,17 +448,17 @@ QString controlParamName (
 
 
 //----------------------------------------------------------------------------
-// synthv1widget_controls_item_delegate -- Custom (tree) list item delegate.
+// synthv1widget_controls::ItemDelegate -- Custom (tree) list item delegate.
 
 // ctor.
-synthv1widget_controls_item_delegate::synthv1widget_controls_item_delegate (
-	QObject *pParent ) : QItemDelegate(pParent)
+synthv1widget_controls::ItemDelegate::ItemDelegate ( QObject *pParent )
+	: QItemDelegate(pParent)
 {
 }
 
 
 // QItemDelegate interface...
-QSize synthv1widget_controls_item_delegate::sizeHint (
+QSize synthv1widget_controls::ItemDelegate::sizeHint (
 	const QStyleOptionViewItem& option, const QModelIndex& index ) const
 {
 	const int x = (index.column() == 1 ? 32 : 4); // Type is special.
@@ -438,10 +466,10 @@ QSize synthv1widget_controls_item_delegate::sizeHint (
 }
 
 
-QWidget *synthv1widget_controls_item_delegate::createEditor ( QWidget *pParent,
+QWidget *synthv1widget_controls::ItemDelegate::createEditor ( QWidget *pParent,
 	const QStyleOptionViewItem& /*option*/, const QModelIndex& index ) const
 {
-	QWidget *pEditor = NULL;
+	QWidget *pEditor = nullptr;
 
 	switch (index.column()) {
 	case 0: // Channel.
@@ -496,7 +524,7 @@ QWidget *synthv1widget_controls_item_delegate::createEditor ( QWidget *pParent,
 	}
 
 #ifdef CONFIG_DEBUG_0
-	qDebug("synthv1widget_controls_item_delegate::createEditor(%p, %d, %d) = %p",
+	qDebug("synthv1widget_controls::ItemDelegate::createEditor(%p, %d, %d) = %p",
 		pParent, index.row(), index.column(), pEditor);
 #endif
 
@@ -504,11 +532,11 @@ QWidget *synthv1widget_controls_item_delegate::createEditor ( QWidget *pParent,
 }
 
 
-void synthv1widget_controls_item_delegate::setEditorData (
+void synthv1widget_controls::ItemDelegate::setEditorData (
 	QWidget *pEditor, const QModelIndex& index ) const
 {
 #ifdef CONFIG_DEBUG_0
-	qDebug("synthv1widget_controls_item_delegate::setEditorData(%p, %d, %d)",
+	qDebug("synthv1widget_controls::ItemDelegate::setEditorData(%p, %d, %d)",
 		pEditor, index.row(), index.column());
 #endif
 
@@ -567,7 +595,7 @@ void synthv1widget_controls_item_delegate::setEditorData (
 }
 
 
-void synthv1widget_controls_item_delegate::setModelData ( QWidget *pEditor,
+void synthv1widget_controls::ItemDelegate::setModelData ( QWidget *pEditor,
 	QAbstractItemModel *pModel,	const QModelIndex& index ) const
 {
 #ifdef CONFIG_DEBUG_0
@@ -656,14 +684,14 @@ synthv1widget_controls::synthv1widget_controls ( QWidget *pParent )
 	QTreeWidget::setSelectionMode(QAbstractItemView::SingleSelection);
 
 	QHeaderView *pHeaderView = QTreeWidget::header();
-#if QT_VERSION < 0x050000
+#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
 	pHeaderView->setResizeMode(QHeaderView::ResizeToContents);
 #else
 	pHeaderView->setSectionResizeMode(QHeaderView::ResizeToContents);
 #endif
 //	pHeaderView->hide();
 
-	QTreeWidget::setItemDelegate(new synthv1widget_controls_item_delegate(this));
+	QTreeWidget::setItemDelegate(new ItemDelegate(this));
 
 	QObject::connect(this,
 		SIGNAL(itemChanged(QTreeWidgetItem *, int)),
